import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import NotFound from "@/pages/not-found";
import Home from "@/pages/Home";
import ListingDetail from "@/pages/ListingDetail";
import CreateListing from "@/pages/CreateListing";
import SearchResults from "@/pages/SearchResults";
import CategoryListings from "@/pages/CategoryListings";
import UserProfile from "@/pages/UserProfile";
import Login from "@/pages/Login";
import Register from "@/pages/Register";
import Header from "@/components/layout/Header";
import Footer from "@/components/layout/Footer";

function Router() {
  return (
    <div className="flex flex-col min-h-screen">
      <Header />
      <div className="flex-grow">
        <Switch>
          <Route path="/" component={Home} />
          <Route path="/listings/:id" component={ListingDetail} />
          <Route path="/create-listing" component={CreateListing} />
          <Route path="/search" component={SearchResults} />
          <Route path="/categories/:slug" component={CategoryListings} />
          <Route path="/profile" component={UserProfile} />
          <Route path="/login" component={Login} />
          <Route path="/register" component={Register} />
          <Route component={NotFound} />
        </Switch>
      </div>
      <Footer />
    </div>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <Router />
      <Toaster />
    </QueryClientProvider>
  );
}

export default App;
